@@ -1,5 +1,4 @@
 //go:build integration
-// +build integration
 
 package tests
 
@@ -18,8 +17,6 @@ import (
 	. "github.com/onsi/gomega"
 
 	. "github.com/weaveworks/eksctl/integration/runner"
-
-	"github.com/weaveworks/eksctl/integration/runner"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/eks"
 	"github.com/weaveworks/eksctl/pkg/utils/names"
@@ -45,24 +42,24 @@ type Params struct {
 	IsGitopsOwnerPersonal    bool
 	KubeconfigTemp           bool
 	TestDirectory            string
-	EksctlCmd                runner.Cmd
-	EksctlCreateCmd          runner.Cmd
-	EksctlCreateNodegroupCmd runner.Cmd
-	EksctlUpgradeCmd         runner.Cmd
-	EksctlUpdateCmd          runner.Cmd
-	EksctlGetCmd             runner.Cmd
-	EksctlSetLabelsCmd       runner.Cmd
-	EksctlUnsetLabelsCmd     runner.Cmd
-	EksctlDeleteCmd          runner.Cmd
-	EksctlDeleteClusterCmd   runner.Cmd
-	EksctlDrainNodeGroupCmd  runner.Cmd
-	EksctlScaleNodeGroupCmd  runner.Cmd
-	EksctlUtilsCmd           runner.Cmd
-	EksctlEnableCmd          runner.Cmd
-	EksctlAnywhereCmd        runner.Cmd
-	EksctlHelpCmd            runner.Cmd
-	EksctlRegisterCmd        runner.Cmd
-	EksctlDeregisterCmd      runner.Cmd
+	EksctlCmd                Cmd
+	EksctlCreateCmd          Cmd
+	EksctlCreateNodegroupCmd Cmd
+	EksctlUpgradeCmd         Cmd
+	EksctlUpdateCmd          Cmd
+	EksctlGetCmd             Cmd
+	EksctlSetLabelsCmd       Cmd
+	EksctlUnsetLabelsCmd     Cmd
+	EksctlDeleteCmd          Cmd
+	EksctlDeleteClusterCmd   Cmd
+	EksctlDrainNodeGroupCmd  Cmd
+	EksctlScaleNodeGroupCmd  Cmd
+	EksctlUtilsCmd           Cmd
+	EksctlEnableCmd          Cmd
+	EksctlAnywhereCmd        Cmd
+	EksctlHelpCmd            Cmd
+	EksctlRegisterCmd        Cmd
+	EksctlDeregisterCmd      Cmd
 	// Keep track of created clusters, for post-tests clean-up.
 	clustersToDelete []string
 }
@@ -82,11 +79,11 @@ func (p *Params) GenerateKubeconfigPath() {
 // GenerateCommands generates eksctl commands with the various options & values
 // provided to this `Params` object.
 func (p *Params) GenerateCommands() {
-	p.EksctlCmd = runner.NewCmd(p.EksctlPath).
+	p.EksctlCmd = NewCmd(p.EksctlPath).
 		WithArgs("--region", p.Region).
 		WithTimeout(30 * time.Minute)
 
-	p.EksctlHelpCmd = runner.NewCmd(p.EksctlPath).
+	p.EksctlHelpCmd = NewCmd(p.EksctlPath).
 		WithArgs("--help").
 		WithTimeout(30 * time.Minute)
 
@@ -138,23 +135,23 @@ func (p *Params) GenerateCommands() {
 		WithArgs("utils").
 		WithTimeout(5 * time.Minute)
 
-	p.EksctlEnableCmd = runner.NewCmd(p.EksctlPath).
+	p.EksctlEnableCmd = NewCmd(p.EksctlPath).
 		WithArgs("enable").
 		WithTimeout(10 * time.Minute)
 
-	p.EksctlRegisterCmd = runner.NewCmd(p.EksctlPath).
+	p.EksctlRegisterCmd = NewCmd(p.EksctlPath).
 		WithArgs("register").
 		WithTimeout(2 * time.Minute)
 
-	p.EksctlDeregisterCmd = runner.NewCmd(p.EksctlPath).
+	p.EksctlDeregisterCmd = NewCmd(p.EksctlPath).
 		WithArgs("deregister").
 		WithTimeout(1 * time.Minute)
 
-	p.EksctlCreateNodegroupCmd = runner.NewCmd(p.EksctlPath).
+	p.EksctlCreateNodegroupCmd = NewCmd(p.EksctlPath).
 		WithArgs("create", "nodegroup").
 		WithTimeout(40 * time.Minute)
 
-	p.EksctlAnywhereCmd = runner.NewCmd(p.EksctlPath).
+	p.EksctlAnywhereCmd = NewCmd(p.EksctlPath).
 		WithArgs("anywhere").
 		WithTimeout(1 * time.Minute)
 }
