@@ -1,8 +1,9 @@
 package nodebootstrap
 
 import (
+	"fmt"
+
 	"github.com/kris-nova/logger"
-	"github.com/pkg/errors"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap/assets"
@@ -31,7 +32,7 @@ func (b *AmazonLinux2) UserData() (string, error) {
 
 	body, err := linuxConfig(b.clusterConfig, al2BootScript, assets.BootstrapAl2Sh, b.clusterDNS, b.ng, scripts...)
 	if err != nil {
-		return "", errors.Wrap(err, "encoding user data")
+		return "", fmt.Errorf("encoding user data: %w", err)
 	}
 
 	logger.Debug("user-data = %s", body)
